[−][src]Enum unicode_types::deseret::Deseret
An enum to represent all characters in the Deseret block.
Variants
CapitalLetterLongI\u{10400}: '𐐀'
CapitalLetterLongE\u{10401}: '𐐁'
CapitalLetterLongA\u{10402}: '𐐂'
CapitalLetterLongAh\u{10403}: '𐐃'
CapitalLetterLongO\u{10404}: '𐐄'
CapitalLetterLongOo\u{10405}: '𐐅'
CapitalLetterShortI\u{10406}: '𐐆'
CapitalLetterShortE\u{10407}: '𐐇'
CapitalLetterShortA\u{10408}: '𐐈'
CapitalLetterShortAh\u{10409}: '𐐉'
CapitalLetterShortO\u{1040a}: '𐐊'
CapitalLetterShortOo\u{1040b}: '𐐋'
CapitalLetterAy\u{1040c}: '𐐌'
CapitalLetterOw\u{1040d}: '𐐍'
CapitalLetterWu\u{1040e}: '𐐎'
CapitalLetterYee\u{1040f}: '𐐏'
CapitalLetterH\u{10410}: '𐐐'
CapitalLetterPee\u{10411}: '𐐑'
CapitalLetterBee\u{10412}: '𐐒'
CapitalLetterTee\u{10413}: '𐐓'
CapitalLetterDee\u{10414}: '𐐔'
CapitalLetterChee\u{10415}: '𐐕'
CapitalLetterJee\u{10416}: '𐐖'
CapitalLetterKay\u{10417}: '𐐗'
CapitalLetterGay\u{10418}: '𐐘'
CapitalLetterEf\u{10419}: '𐐙'
CapitalLetterVee\u{1041a}: '𐐚'
CapitalLetterEth\u{1041b}: '𐐛'
CapitalLetterThee\u{1041c}: '𐐜'
CapitalLetterEs\u{1041d}: '𐐝'
CapitalLetterZee\u{1041e}: '𐐞'
CapitalLetterEsh\u{1041f}: '𐐟'
CapitalLetterZhee\u{10420}: '𐐠'
CapitalLetterEr\u{10421}: '𐐡'
CapitalLetterEl\u{10422}: '𐐢'
CapitalLetterEm\u{10423}: '𐐣'
CapitalLetterEn\u{10424}: '𐐤'
CapitalLetterEng\u{10425}: '𐐥'
CapitalLetterOi\u{10426}: '𐐦'
CapitalLetterEw\u{10427}: '𐐧'
SmallLetterLongI\u{10428}: '𐐨'
SmallLetterLongE\u{10429}: '𐐩'
SmallLetterLongA\u{1042a}: '𐐪'
SmallLetterLongAh\u{1042b}: '𐐫'
SmallLetterLongO\u{1042c}: '𐐬'
SmallLetterLongOo\u{1042d}: '𐐭'
SmallLetterShortI\u{1042e}: '𐐮'
SmallLetterShortE\u{1042f}: '𐐯'
SmallLetterShortA\u{10430}: '𐐰'
SmallLetterShortAh\u{10431}: '𐐱'
SmallLetterShortO\u{10432}: '𐐲'
SmallLetterShortOo\u{10433}: '𐐳'
SmallLetterAy\u{10434}: '𐐴'
SmallLetterOw\u{10435}: '𐐵'
SmallLetterWu\u{10436}: '𐐶'
SmallLetterYee\u{10437}: '𐐷'
SmallLetterH\u{10438}: '𐐸'
SmallLetterPee\u{10439}: '𐐹'
SmallLetterBee\u{1043a}: '𐐺'
SmallLetterTee\u{1043b}: '𐐻'
SmallLetterDee\u{1043c}: '𐐼'
SmallLetterChee\u{1043d}: '𐐽'
SmallLetterJee\u{1043e}: '𐐾'
SmallLetterKay\u{1043f}: '𐐿'
SmallLetterGay\u{10440}: '𐑀'
SmallLetterEf\u{10441}: '𐑁'
SmallLetterVee\u{10442}: '𐑂'
SmallLetterEth\u{10443}: '𐑃'
SmallLetterThee\u{10444}: '𐑄'
SmallLetterEs\u{10445}: '𐑅'
SmallLetterZee\u{10446}: '𐑆'
SmallLetterEsh\u{10447}: '𐑇'
SmallLetterZhee\u{10448}: '𐑈'
SmallLetterEr\u{10449}: '𐑉'
SmallLetterEl\u{1044a}: '𐑊'
SmallLetterEm\u{1044b}: '𐑋'
SmallLetterEn\u{1044c}: '𐑌'
SmallLetterEng\u{1044d}: '𐑍'
SmallLetterOi\u{1044e}: '𐑎'
Methods
impl Deseret[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case